<?php
// app/controllers/userController.php
ob_start();
require_once(__DIR__ . '/../Models/User.php');


class UserController {
    private $userModel;

    public function __construct() {
        $this->userModel = new UserModel();
    }

    public function createUser($name, $username, $email, $hashedPass, $isAdmin) {
        return $this->userModel->createUser($name, $username, $email, $hashedPass, $isAdmin);
    }

    public function getUser($userId) {
        return $this->userModel->getUser($userId);
    }

    public function updateUser($userId, $name, $username, $email, $hashedPass, $isAdmin) {
        return $this->userModel->updateUser($userId, $name, $username, $email, $hashedPass, $isAdmin);
    }

    public function deleteUser($userId) {
        return $this->userModel->deleteUser($userId);
    }

    public function getAllUsers() {
        return $this->userModel->getAllUsers();
    }
    
    public function registerUser($name, $username, $email, $password, $isAdmin) {
        return $this->createUser($name, $username, $email, password_hash($password,PASSWORD_DEFAULT), $isAdmin);
    }

    public function loginByEmail($email,$password) {
        $user = $this->userModel->getUserByEmail($email);
        if ($user !== false && password_verify($password, $user['user_hashedPass'])) {
            session_start();
            $_SESSION["user_id"] = $user['user_ID'];
            return "success";
        } else {
            return "wrong credentials";
        }
    }

    public function loginByUsername($username,$password) {
        $user = $this->userModel->getUserByUsername($username);
        if ($user !== false && password_verify($password, $user['user_hashedPass'])) {
            session_start();
            $_SESSION["user_id"] = $user['user_ID'];
            return "success";
        } else {
            session_start();
            return "wrong credentials";
        }
    }
    
    public function logout() {
        session_start();
        if (isset($_SESSION["user_id"])) {
            unset($_SESSION["user_id"]);
            session_destroy();
            return "logout successful";
        } else {
            return "user not logged in";
        }
    }
    
    public function editProfile($user_id, $name, $username, $email) {
        return $this->userModel->editProfile($user_id, $name, $username, $email);
    }
    
    public function handleRequest() {
        if (isset($_POST['userAction'])) {
            if ($_POST['userAction'] === 'login') {
                unset($_POST['userAction']);
                $emailOrUsername = $_POST['loginIdentifier'];
                $password = $_POST['loginPassword'];
                if (filter_var($emailOrUsername, FILTER_VALIDATE_EMAIL)){
                    if ($this->loginByEmail($emailOrUsername, $password) === "success") {
                        header("Location:Views/home/home.php");
                        ob_end_flush();
                    } else {
                        session_start();
                        $_SESSION['message'] = "wrong credentials";
                        header("Location:Views/login/login.php");
                        ob_end_flush();
                    }
                } else {
                    if ($this->loginByUsername($emailOrUsername,$password) === "success") {
                        header("Location:Views/home/home.php");
                        ob_end_flush();
                    } else {
                        session_start();
                        $_SESSION['message'] = "wrong credentials";
                        header("Location:Views/login/login.php");
                        ob_end_flush();
                    }
                }
            } elseif ($_POST['userAction'] === 'createUser') {
                unset($_POST['userAction']);
                $userName = $_POST['userName'];
                $userUsername = $_POST['userUsername'];
                $userEmail = $_POST['userEmail'];
                $userPassword = $_POST['userPassword'];
                $isAdmin = isset($_POST['isAdmin']) ? 1 : 0;
                $response = $this->registerUser($userName,$userUsername,$userEmail,$userPassword,$isAdmin);
                $success = $response['success'];
                if($success){
                    session_start();
                    $_SESSION['message'] = "You have successfully registered. Please log in";
                    header("Location:Views/login/login.php");
                    ob_end_flush();
                } else {
                    session_start();
                    $_SESSION['error_message'] = $response['message'];
                    header("Location:Views/login/register.php");
                    ob_end_flush();
                }
            } elseif ($_POST['userAction'] === 'logout') {
                unset($_POST['userAction']);
                $this->logout();
                session_start();
                $_SESSION['message'] = "User logged out successfully. Please log in again.";
                header("Location:Views/login/login.php");
                ob_end_flush();
            } elseif ($_POST['userAction'] === 'viewProfile') {
                unset($_POST['userAction']);
                // Display existing data
                if (isset($_SESSION['user_id'])) {
                    $userId = $_SESSION['user_id'];
                    echo "User ID from session: " . $userId; // Debugging
    
                    $userData = $this->getUser($userId);

                    if ($userData !== null) {
                        $_SESSION['userData'] = $userData;
                        header("Location:Views/profile/view_profile.php");
                        ob_end_flush();
                    } else {
                        echo "User data not available.";
                    }
                } else {
                    echo "User ID not set in session."; // Debugging
                }
    
            }  elseif ($_POST['userAction'] === 'editProfile') {
                unset($_POST['userAction']);
                $userId = $_SESSION['user_id']; 
                $newUserName = $_POST['user_name'];
                $newUsername = $_POST['user_username'];
                $newUserEmail = $_POST['user_email'];

                $this->editProfile($_SESSION['user_id'], $newUserName, $newUsername, $newUserEmail);

                header('Location:Views/profile/view_profile.php');
                ob_end_flush();
        } 
    }
        if (isset($_GET['userAction'])) {
            if ($_GET['userAction'] === 'getUser') {
                unset($_GET['userAction']);
                session_start();
                echo json_encode($this->getUser($_SESSION['user_id']));
            }
        }
    }

}
?>