<?php
// app/models/Ticket.php

require_once(__DIR__ . '/../../db/connect.php');


class TicketModel {
    public function createTicket($name, $eventId) {
        global $db;

        $stmt = $db->prepare("INSERT INTO tickets (ticket_name, event_id) VALUES (?, ?)");
        $stmt->execute([$name, $eventId]);

        return "Ticket created successfully";
    }

    public function getTicket($ticketId) {
        global $db;

        $stmt = $db->prepare("SELECT * FROM tickets WHERE ticket_id = ?");
        $stmt->execute([$ticketId]);

        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function updateTicket($ticketId, $name, $eventId) {
        global $db;

        $stmt = $db->prepare("UPDATE tickets SET ticket_name = ?, event_id = ? WHERE ticket_id = ?");
        $stmt->execute([$name, $eventId, $ticketId]);

        return "Ticket updated successfully";
    }

    public function updateTicketByEventId($eventId, $name) {
        global $db;

        $stmt = $db->prepare("UPDATE tickets SET ticket_name = ? WHERE event_id = ?");
        $stmt->execute([$name, $eventId]);

        return "Ticket updated successfully";
    }

    public function deleteTicket($ticketId) {
        global $db;

        $stmt = $db->prepare("DELETE FROM tickets WHERE ticket_id = ?");
        $stmt->execute([$ticketId]);

        return "Ticket deleted successfully";
    }

    public function getSmallestAvailableTicket($eventId) {
        global $db;

        $stmt = $db->prepare("
            SELECT t.*, e.*
            FROM tickets t
            JOIN events e ON t.event_id = e.event_id
            WHERE t.event_id = :eventId
            AND NOT EXISTS (
                SELECT 1
                FROM pembelian p
                WHERE p.ticket_id = t.ticket_id
            )
            ORDER BY t.ticket_id ASC
            LIMIT 1
        ");

        $stmt->bindParam(':eventId', $eventId, PDO::PARAM_INT);
        $stmt->execute();

        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
}
?>
